# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc60
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel
from polyaxon_sdk.models.v1_bayes import V1Bayes
from polyaxon_sdk.models.v1_grid_search import V1GridSearch
from polyaxon_sdk.models.v1_hyperband import V1Hyperband
from polyaxon_sdk.models.v1_hyperopt import V1Hyperopt
from polyaxon_sdk.models.v1_iterative import V1Iterative
from polyaxon_sdk.models.v1_mapping import V1Mapping
from polyaxon_sdk.models.v1_random_search import V1RandomSearch

class V1Matrix(BaseModel):
    """
    V1Matrix
    """
    random: Optional[V1RandomSearch] = None
    grid: Optional[V1GridSearch] = None
    hyperband: Optional[V1Hyperband] = None
    bayes: Optional[V1Bayes] = None
    hyperopt: Optional[V1Hyperopt] = None
    iterative: Optional[V1Iterative] = None
    mapping: Optional[V1Mapping] = None
    __properties = ["random", "grid", "hyperband", "bayes", "hyperopt", "iterative", "mapping"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Matrix:
        """Create an instance of V1Matrix from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of random
        if self.random:
            _dict['random'] = self.random.to_dict()
        # override the default output from pydantic by calling `to_dict()` of grid
        if self.grid:
            _dict['grid'] = self.grid.to_dict()
        # override the default output from pydantic by calling `to_dict()` of hyperband
        if self.hyperband:
            _dict['hyperband'] = self.hyperband.to_dict()
        # override the default output from pydantic by calling `to_dict()` of bayes
        if self.bayes:
            _dict['bayes'] = self.bayes.to_dict()
        # override the default output from pydantic by calling `to_dict()` of hyperopt
        if self.hyperopt:
            _dict['hyperopt'] = self.hyperopt.to_dict()
        # override the default output from pydantic by calling `to_dict()` of iterative
        if self.iterative:
            _dict['iterative'] = self.iterative.to_dict()
        # override the default output from pydantic by calling `to_dict()` of mapping
        if self.mapping:
            _dict['mapping'] = self.mapping.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Matrix:
        """Create an instance of V1Matrix from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Matrix.parse_obj(obj)

        _obj = V1Matrix.parse_obj({
            "random": V1RandomSearch.from_dict(obj.get("random")) if obj.get("random") is not None else None,
            "grid": V1GridSearch.from_dict(obj.get("grid")) if obj.get("grid") is not None else None,
            "hyperband": V1Hyperband.from_dict(obj.get("hyperband")) if obj.get("hyperband") is not None else None,
            "bayes": V1Bayes.from_dict(obj.get("bayes")) if obj.get("bayes") is not None else None,
            "hyperopt": V1Hyperopt.from_dict(obj.get("hyperopt")) if obj.get("hyperopt") is not None else None,
            "iterative": V1Iterative.from_dict(obj.get("iterative")) if obj.get("iterative") is not None else None,
            "mapping": V1Mapping.from_dict(obj.get("mapping")) if obj.get("mapping") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc60
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, StrictStr, conlist

class V1EntitiesTags(BaseModel):
    """
    V1EntitiesTags
    """
    uuids: Optional[conlist(StrictStr)] = None
    tags: Optional[conlist(StrictStr)] = None
    __properties = ["uuids", "tags"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1EntitiesTags:
        """Create an instance of V1EntitiesTags from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1EntitiesTags:
        """Create an instance of V1EntitiesTags from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1EntitiesTags.parse_obj(obj)

        _obj = V1EntitiesTags.parse_obj({
            "uuids": obj.get("uuids"),
            "tags": obj.get("tags")
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc60
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictStr, conlist
from polyaxon_sdk.models.v1_environment import V1Environment
from polyaxon_sdk.models.v1_init import V1Init

class V1Job(BaseModel):
    """
    V1Job
    """
    kind: Optional[StrictStr] = 'job'
    environment: Optional[V1Environment] = None
    connections: Optional[conlist(StrictStr)] = None
    volumes: Optional[conlist(Dict[str, Any])] = Field(None, description="Volumes is a list of volumes that can be mounted.")
    init: Optional[conlist(V1Init)] = None
    sidecars: Optional[conlist(Dict[str, Any])] = None
    container: Optional[Dict[str, Any]] = None
    __properties = ["kind", "environment", "connections", "volumes", "init", "sidecars", "container"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Job:
        """Create an instance of V1Job from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of environment
        if self.environment:
            _dict['environment'] = self.environment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in init (list)
        _items = []
        if self.init:
            for _item in self.init:
                if _item:
                    _items.append(_item.to_dict())
            _dict['init'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Job:
        """Create an instance of V1Job from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Job.parse_obj(obj)

        _obj = V1Job.parse_obj({
            "kind": obj.get("kind") if obj.get("kind") is not None else 'job',
            "environment": V1Environment.from_dict(obj.get("environment")) if obj.get("environment") is not None else None,
            "connections": obj.get("connections"),
            "volumes": obj.get("volumes"),
            "init": [V1Init.from_dict(_item) for _item in obj.get("init")] if obj.get("init") is not None else None,
            "sidecars": obj.get("sidecars"),
            "container": obj.get("container")
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc60
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field
from polyaxon_sdk.models.v1_dag_ref import V1DagRef
from polyaxon_sdk.models.v1_hub_ref import V1HubRef
from polyaxon_sdk.models.v1_path_ref import V1PathRef
from polyaxon_sdk.models.v1_url_ref import V1UrlRef

class V1Reference(BaseModel):
    """
    V1Reference
    """
    hub_ref: Optional[V1HubRef] = Field(None, alias="hubRef")
    dag_ref: Optional[V1DagRef] = Field(None, alias="dagRef")
    url_ref: Optional[V1UrlRef] = Field(None, alias="urlRef")
    path_ref: Optional[V1PathRef] = Field(None, alias="pathRef")
    __properties = ["hubRef", "dagRef", "urlRef", "pathRef"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Reference:
        """Create an instance of V1Reference from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of hub_ref
        if self.hub_ref:
            _dict['hubRef'] = self.hub_ref.to_dict()
        # override the default output from pydantic by calling `to_dict()` of dag_ref
        if self.dag_ref:
            _dict['dagRef'] = self.dag_ref.to_dict()
        # override the default output from pydantic by calling `to_dict()` of url_ref
        if self.url_ref:
            _dict['urlRef'] = self.url_ref.to_dict()
        # override the default output from pydantic by calling `to_dict()` of path_ref
        if self.path_ref:
            _dict['pathRef'] = self.path_ref.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Reference:
        """Create an instance of V1Reference from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Reference.parse_obj(obj)

        _obj = V1Reference.parse_obj({
            "hub_ref": V1HubRef.from_dict(obj.get("hubRef")) if obj.get("hubRef") is not None else None,
            "dag_ref": V1DagRef.from_dict(obj.get("dagRef")) if obj.get("dagRef") is not None else None,
            "url_ref": V1UrlRef.from_dict(obj.get("urlRef")) if obj.get("urlRef") is not None else None,
            "path_ref": V1PathRef.from_dict(obj.get("pathRef")) if obj.get("pathRef") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc60
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class V1RunEdgeKind(str, Enum):
    """
    V1RunEdgeKind
    """

    """
    allowed enum values
    """
    ACTION = 'action'
    EVENT = 'event'
    HOOK = 'hook'
    DAG = 'dag'
    JOIN = 'join'
    RUN = 'run'
    TB = 'tb'
    BUILD = 'build'
    MANUAL = 'manual'




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc60
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from inspect import getfullargspec
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class V1ScheduleKind(str, Enum):
    """
    V1ScheduleKind
    """

    """
    allowed enum values
    """
    CRON = 'cron'
    INTERVAL = 'interval'
    DATETIME = 'datetime'




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc60
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, Optional
from pydantic import BaseModel, StrictInt
from polyaxon_sdk.models.agent_state_response_agent_state import AgentStateResponseAgentState
from polyaxon_sdk.models.v1_statuses import V1Statuses

class V1AgentStateResponse(BaseModel):
    """
    V1AgentStateResponse
    """
    status: Optional[V1Statuses] = None
    state: Optional[AgentStateResponseAgentState] = None
    live_state: Optional[StrictInt] = None
    compatible_updates: Optional[Dict[str, Any]] = None
    __properties = ["status", "state", "live_state", "compatible_updates"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1AgentStateResponse:
        """Create an instance of V1AgentStateResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of state
        if self.state:
            _dict['state'] = self.state.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1AgentStateResponse:
        """Create an instance of V1AgentStateResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1AgentStateResponse.parse_obj(obj)

        _obj = V1AgentStateResponse.parse_obj({
            "status": obj.get("status"),
            "state": AgentStateResponseAgentState.from_dict(obj.get("state")) if obj.get("state") is not None else None,
            "live_state": obj.get("live_state"),
            "compatible_updates": obj.get("compatible_updates")
        })
        return _obj




# coding: utf-8

"""
    Polyaxon SDKs and REST API specification.

         # noqa: E501

    The version of the OpenAPI document: 2.0.0-rc60
    Contact: contact@polyaxon.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel, StrictStr, conlist
from polyaxon_sdk.models.v1_team_settings import V1TeamSettings

class V1Team(BaseModel):
    """
    V1Team
    """
    uuid: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    projects: Optional[conlist(StrictStr)] = None
    component_hubs: Optional[conlist(StrictStr)] = None
    model_registries: Optional[conlist(StrictStr)] = None
    settings: Optional[V1TeamSettings] = None
    created_at: Optional[datetime] = None
    updated_at: Optional[datetime] = None
    __properties = ["uuid", "name", "projects", "component_hubs", "model_registries", "settings", "created_at", "updated_at"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> V1Team:
        """Create an instance of V1Team from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of settings
        if self.settings:
            _dict['settings'] = self.settings.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> V1Team:
        """Create an instance of V1Team from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return V1Team.parse_obj(obj)

        _obj = V1Team.parse_obj({
            "uuid": obj.get("uuid"),
            "name": obj.get("name"),
            "projects": obj.get("projects"),
            "component_hubs": obj.get("component_hubs"),
            "model_registries": obj.get("model_registries"),
            "settings": V1TeamSettings.from_dict(obj.get("settings")) if obj.get("settings") is not None else None,
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at")
        })
        return _obj

